@@ -11,10 +11,10 @@
 #ifndef EMAGRAM_H
 #define EMAGRAM_H
 
-#include <Coordinate.h>
-#include <TephigramAttributes.h>
-#include <Transformation.h>
-#include <XmlNode.h>
+#include "Coordinate.h"
+#include "TephigramAttributes.h"
+#include "Transformation.h"
+#include "XmlNode.h"
 
 namespace magics {
 
@@ -28,24 +28,24 @@ namespace magics {
 class Emagram : public Transformation, public TephigramAttributes {
 public:
     Emagram();
-    ~Emagram();
+    ~Emagram() override;
 
     /*!
       \brief sets  from an XML node
     */
-    void set(const XmlNode& node) {
+    void set(const XmlNode& node) override {
         Transformation::set(node);
         TephigramAttributes::set(node);
     }
     /*!
       \brief sets  from a map
     */
-    void set(const map<string, string>& map) {
+    void set(const map<string, string>& map) override {
         Transformation::set(map);
         TephigramAttributes::set(map);
     }
 
-    virtual Transformation* clone() const {
+    virtual Transformation* clone() const override {
         Emagram* transformation = new Emagram();
         return transformation;
     }
@@ -53,56 +53,56 @@ public:
     /*!
     \\brief Initialise the projection
     */
-    virtual void init();
+    virtual void init() override;
     /*!
     \\brief
     */
-    virtual PaperPoint operator()(const UserPoint&) const;
+    virtual PaperPoint operator()(const UserPoint&) const override;
     /*!
     \\brief
     */
-    virtual bool getAutomaticX() const { return x_automatic_; }
-    virtual bool getAutomaticY() const { return y_automatic_; }
-    virtual void setMinMaxX(double, double);
-    virtual void setMinMaxY(double, double);
-    virtual PaperPoint operator()(const PaperPoint&) const;
+    virtual bool getAutomaticX() const override { return x_automatic_; }
+    virtual bool getAutomaticY() const override { return y_automatic_; }
+    virtual void setMinMaxX(double, double) override;
+    virtual void setMinMaxY(double, double) override;
+    virtual PaperPoint operator()(const PaperPoint&) const override;
     /*!
     \\brief
     */
-    virtual void revert(const PaperPoint&, UserPoint&) const;
+    virtual void revert(const PaperPoint&, UserPoint&) const override;
 
-    void revert(const vector<std::pair<double, double> >&, vector<std::pair<double, double> >&) const;
+    void revert(const vector<std::pair<double, double> >&, vector<std::pair<double, double> >&) const override;
 
 
     /*!
     \\brief Does the projection needs the coastalines to be shifted!
     */
-    virtual bool needShiftedCoastlines() const;
+    virtual bool needShiftedCoastlines() const override;
     /*!
     \\brief set the aspect ratio!
     */
-    virtual void aspectRatio(double&, double&);
+    virtual void aspectRatio(double&, double&) override;
     /*!
     \\brief set the bounding box!
     */
-    virtual void boundingBox(double&, double&, double&, double&) const;
+    virtual void boundingBox(double&, double&, double&, double&) const override;
 
     /*!
     \\brief return the xmin in user coordinates!
     */
-    virtual double getMinX() const;
+    virtual double getMinX() const override;
     /*!
     \\brief return the ymin in user coordinates!
     */
-    virtual double getMinY() const;
+    virtual double getMinY() const override;
     /*!
     \\brief return the xmax in user coordinates!
     */
-    virtual double getMaxX() const;
+    virtual double getMaxX() const override;
     /*!
     \\brief return the ymax in user coordinates!
     */
-    virtual double getMaxY() const;
+    virtual double getMaxY() const override;
     /*!
     \\brief set the xmin in user coordinates!
     */
@@ -122,32 +122,32 @@ public:
     /*!
     \\brief return the xmin in projection coordinates!
     */
-    virtual double getMinPCX() const;
+    virtual double getMinPCX() const override;
     /*!
     \\brief return the ymin in projection coordinates!
     */
-    virtual double getMinPCY() const;
+    virtual double getMinPCY() const override;
     /*!
     \\brief return the xmax in projection coordinates!
     */
-    virtual double getMaxPCX() const;
+    virtual double getMaxPCX() const override;
     virtual double getMaxTestPCX() const;
     /*!
     \\brief return the ymax in projection coordinates!
     */
-    virtual double getMaxPCY() const;
+    virtual double getMaxPCY() const override;
 
-    virtual Polyline& getPCBoundingBox() const;
-    virtual Polyline& getUserBoundingBox() const;
+    virtual Polyline& getPCBoundingBox() const override;
+    virtual Polyline& getUserBoundingBox() const override;
 
-    virtual void setDefinition(const string&);
-    void getNewDefinition(const UserPoint&, const UserPoint&, string&) const;
-    bool in(const PaperPoint& point) const;
-    void operator()(const Polyline& poly, BasicGraphicsObjectContainer& out) const;
+    virtual void setDefinition(const string&) override;
+    void getNewDefinition(const UserPoint&, const UserPoint&, string&) const override;
+    bool in(const PaperPoint& point) const override;
+    void operator()(const Polyline& poly, BasicGraphicsObjectContainer& out) const override;
 
 protected:
     //! Method to print string about this class on to a stream of type ostream (virtual).
-    virtual void print(ostream&) const;
+    virtual void print(ostream&) const override;
 
     double minPCX_;
     double maxPCX_;
