@@ -21,6 +21,7 @@
 
 
 #include "BoxPlotDecoder.h"
+#include "MagicsGlobal.h"
 
 using namespace magics;
 
@@ -77,5 +78,8 @@ void BoxPlotDecoder::getReady(const Transformation& transformation) {
             x_.push_back(transformation.x(*x));
     }
     catch (...) {
+        if (MagicsGlobal::strict()) {
+            throw;
+        }
     }
 }
