@@ -7,18 +7,14 @@
 
  ***************************** LICENSE END *************************************/
 
-// MvObs.h,   vk july94
-//        rev vk 010724
-
 #ifndef MvObs_DEFINED_
 #define MvObs_DEFINED_
 
-#ifdef MV_BUFRDC_TEST
-#include "MvBufr.h"
-#endif
-
 #include "MvBufrObs.h"
 #include "MvObsSet.h"
 
+#ifdef METVIEW_PREPBUFR
+#include "MvPrepBufrPrep.h"
 #endif
-// MvObs_DEFINED_
+
+#endif  // MvObs_DEFINED_
