@@ -25,6 +25,7 @@
 #include "IntervalMap.h"
 #include "Layout.h"
 #include "PointsHandler.h"
+#include "MagicsGlobal.h"
 
 using namespace magics;
 
@@ -58,6 +59,9 @@ void Histogram::bean(PointsHandler& points) {
             count->second++;
         }
         catch (...) {
+            if (MagicsGlobal::strict()) {
+                throw;
+            }
             // MagLog::debug() <<  points.current().value() << " is not in range..." << endl;
         }
 
@@ -135,8 +139,11 @@ void Histogram::visit(const IntervalMap<Colour>& beans, Data& data, PointsHandle
         bean(points);
     }
 
-    if (points.empty() || counter_.empty())
+    if (points.empty() || counter_.empty()) {
+        delete cartesian;
         return;
+    }
+
     vector<int> y;
     vector<double> x;
     for (IntervalMap<int>::const_iterator count = counter_.begin(); count != counter_.end(); ++count) {
@@ -178,7 +185,7 @@ void Histogram::visit(const IntervalMap<Colour>& beans, Data& data, PointsHandle
     Polyline* frame = new Polyline();
     frame->setColour(Colour("navy"));
     frame->setThickness(1);
-    frame->setLineStyle(M_SOLID);
+    frame->setLineStyle(LineStyle::SOLID);
     frame->push_back(PaperPoint(xmin_, ymin_));
     frame->push_back(PaperPoint(xmax_, ymin_));
     frame->push_back(PaperPoint(xmax_, ymax_));
@@ -194,20 +201,21 @@ void Histogram::visit(const IntervalMap<Colour>& beans, Data& data, PointsHandle
         Text* val = new Text();
         val->addText(*tick, Colour("navy"), font_size);
         val->push_back(PaperPoint(left, *tick));
-        val->setVerticalAlign(MHALF);
-        val->setJustification(MRIGHT);
+        val->setVerticalAlign(VerticalAlign::HALF);
+        val->setJustification(Justification::RIGHT);
         visitor.push_back(val);
         Polyline* grid = new Polyline();
         grid->setColour(Colour("grey"));
         grid->setThickness(1);
-        grid->setLineStyle(M_DOT);
+        grid->setLineStyle(LineStyle::DOT);
         grid->push_back(PaperPoint(xmin_, *tick));
         grid->push_back(PaperPoint(xmax_, *tick));
         visitor.push_back(grid);
         grid = new Polyline();
         grid->setColour(Colour("navy"));
         grid->setThickness(1);
-        grid->setLineStyle(M_SOLID);
+        grid->setLineStyle(LineStyle::DOT);
+        grid->setLineStyle(LineStyle::SOLID);
         grid->push_back(PaperPoint(xmin_ - (width_ * 0.025), *tick));
         grid->push_back(PaperPoint(xmin_, *tick));
         visitor.push_back(grid);
@@ -224,7 +232,7 @@ void Histogram::visit(const IntervalMap<Colour>& beans, Data& data, PointsHandle
         Polyline* grid = new Polyline();
         grid->setColour(Colour("grey"));
         grid->setThickness(1);
-        grid->setLineStyle(M_DOT);
+        grid->setLineStyle(LineStyle::DOT);
         grid->push_back(PaperPoint(count->first.min_, ymin_));
         grid->push_back(PaperPoint(count->first.min_, ymax_));
         visitor.push_back(grid);
@@ -235,7 +243,7 @@ void Histogram::visit(const IntervalMap<Colour>& beans, Data& data, PointsHandle
         bar = new Polyline();
         bar->setColour(Colour("navy"));
         bar->setThickness(1);
-        bar->setLineStyle(M_SOLID);
+        bar->setLineStyle(LineStyle::SOLID);
 
         bar->setFilled(true);
         bar->setFillColour(colour);
@@ -260,8 +268,8 @@ void Histogram::visit(const IntervalMap<Colour>& beans, Data& data, PointsHandle
         if (barCnt % barLabelFreq == 0) {
             Text* from = new Text();
             from->addText(count->first.min_, Colour("navy"), font_size);
-            from->setVerticalAlign(MTOP);
-            from->setJustification(MLEFT);
+            from->setVerticalAlign(VerticalAlign::TOP);
+            from->setJustification(Justification::LEFT);
             from->setAngle(45.);
             from->push_back(PaperPoint(count->first.min_, bottom));
 
@@ -276,7 +284,7 @@ void Histogram::visit(const IntervalMap<Colour>& beans, Data& data, PointsHandle
         /*grid = new Polyline();
         grid->setColour(Colour("navy"));
         grid->setThickness(1);
-        grid->setLineStyle(M_DASH);
+        grid->setLineStyle(LineStyle::DASH);
         grid->push_back(PaperPoint(xmin_, count->second));
         grid->push_back(PaperPoint(count->first.min_, count->second));
         visitor.push_back(grid);*/
@@ -284,7 +292,7 @@ void Histogram::visit(const IntervalMap<Colour>& beans, Data& data, PointsHandle
         Polyline* vert = new Polyline();
         vert->setColour(Colour("navy"));
         vert->setThickness(1);
-        vert->setLineStyle(M_SOLID);
+        vert->setLineStyle(LineStyle::SOLID);
         vert->push_back(PaperPoint(count->first.min_, ymin_));
         vert->push_back(PaperPoint(count->first.min_, ymin_ - (height_ * 0.025)));
         visitor.push_back(vert);
@@ -295,7 +303,7 @@ void Histogram::visit(const IntervalMap<Colour>& beans, Data& data, PointsHandle
     Polyline* vert = new Polyline();
     vert->setColour(Colour("navy"));
     vert->setThickness(1);
-    vert->setLineStyle(M_SOLID);
+    vert->setLineStyle(LineStyle::SOLID);
     vert->push_back(PaperPoint(last, ymin_));
     vert->push_back(PaperPoint(last, ymin_ - (height_ * 0.025)));
     visitor.push_back(vert);
